import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';
import { useData } from './useData';
import { AxisLeft } from './AxisLeft';
import { AxisBottom } from './AxisBottom';
import { Marks } from './Marks';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 20,
  right: 30,
  left: 80,
  bottom: 110,
};

const xValue = d => d.Country;
const yValue = d => d.Population;

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const yTickOffset = 5;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.2);

  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisLeft yScale={yScale} />

        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          yTickOffset={yTickOffset}
        />

        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          innerHeight={innerHeight}
          xValue={xValue}
          yValue={yValue}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
